@@ -4,6 +4,7 @@ import (
 	"flag"
 	"io"
 	"io/fs"
+	"runtime/debug"
 )
 
 // Option is a function that can be passed to WithOptions.
@@ -18,6 +19,16 @@ func WithBuildInfo(version, commit, date string) Option {
 	}
 }
 
+// WithGoModInfo reads build info and sets its fields, if its available.
+func WithGoModInfo() Option {
+	return func(p *Program) {
+		if info, ok := debug.ReadBuildInfo(); ok && info.Main.Sum != "" {
+			p.modVersion = info.Main.Version
+			p.modSum = info.Main.Sum
+		}
+	}
+}
+
 // WithLogFile sets the path to the log file.
 func WithLogFile(path string) Option {
 	return func(p *Program) {
